Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/core
diff options
context:
space:
mode:
authorVinicius Cubas Brand <viniciuscb@gmail.com>2017-09-30 00:43:04 +0300
committerMorris Jobke <hey@morrisjobke.de>2019-03-13 02:31:38 +0300
commit9bb13fb05fffe9af94f1e57866a025382b71f5a4 (patch)
treedb9f20a2bc3c90be8958398e8e50efe02a81ef6c /core
parentf0c85a0f5f84f6bacd4a58520669a71aff944660 (diff)
Created infrastructure to show circles' shared files
There is a proposal to allow users to filter files shared to circles. This commit is needed to provide the infrastucture for it. Issue: https://github.com/nextcloud/circles/issues/137 Changes to comply to https://github.com/coletivoEITA/circles/pull/2 Polishing: get files shared to circles in caldav Signed-off-by: Vinicius Cubas Brand <viniciuscb@gmail.com> Signed-off-by: Maxence Lange <maxence@artificial-owl.com> Signed-off-by: Morris Jobke <hey@morrisjobke.de>
Diffstat (limited to 'core')
-rw-r--r--core/js/files/client.js8
1 files changed, 6 insertions, 2 deletions
diff --git a/core/js/files/client.js b/core/js/files/client.js
index 2017becf87c..98874d165bf 100644
--- a/core/js/files/client.js
+++ b/core/js/files/client.js
@@ -503,7 +503,7 @@
/**
* Fetches a flat list of files filtered by a given filter criteria.
* (currently only system tags is supported)
*
* @param {Object} filter filter criteria
* @param {Object} [filter.systemTagIds] list of system tag ids to filter by
@@ -525,7 +525,8 @@
properties = options.properties;
}
- if (!filter || (!filter.systemTagIds && _.isUndefined(filter.favorite))) {
+ if (!filter ||
+ (!filter.systemTagIds && _.isUndefined(filter.favorite) && !filter.circlesIds) ) {
throw 'Missing filter argument';
}
@@ -551,6 +552,9 @@
_.each(filter.systemTagIds, function(systemTagIds) {
body += ' <oc:systemtag>' + escapeHTML(systemTagIds) + '</oc:systemtag>\n';
});
+ _.each(filter.circlesIds, function(circlesIds) {
+ body += ' <oc:circle>' + escapeHTML(circlesIds) + '</oc:circle>\n';
+ });
if (filter.favorite) {
body += ' <oc:favorite>' + (filter.favorite ? '1': '0') + '</oc:favorite>\n';
}
@@ -503,7 +503,7 @@
/**
* Fetches a flat list of files filtered by a given filter criteria.
- * (currently only system tags is supported)
+ * (currently system tags and circles are supported)
*
* @param {Object} filter filter criteria